Index: code/branches/cpp11_v2/src/modules/questsystem/GlobalQuest.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/GlobalQuest.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/GlobalQuest.cc	(revision 10765)
@@ -138,5 +138,5 @@
     bool GlobalQuest::isStartable(const PlayerInfo* player) const
     {
-        if(!(this->getParentQuest() == NULL || this->getParentQuest()->isActive(player)))
+        if(!(this->getParentQuest() == nullptr || this->getParentQuest()->isActive(player)))
             return false;
 
@@ -198,5 +198,5 @@
         The status to be set.
     @return
-        Returns false if player is NULL.
+        Returns false if player is nullptr.
     */
     bool GlobalQuest::setStatus(PlayerInfo* player, const QuestStatus::Value & status)
@@ -249,5 +249,5 @@
             i--;
         }
-        return NULL;
+        return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/modules/questsystem/LocalQuest.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/LocalQuest.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/LocalQuest.cc	(revision 10765)
@@ -128,5 +128,5 @@
     bool LocalQuest::isStartable(const PlayerInfo* player) const
     {
-        if(!(this->getParentQuest() == NULL || this->getParentQuest()->isActive(player)))
+        if(!(this->getParentQuest() == nullptr || this->getParentQuest()->isActive(player)))
             return false;
 
@@ -188,5 +188,5 @@
         The status to be set.
     @return
-        Returns false if player is NULL.
+        Returns false if player is nullptr.
     */
     bool LocalQuest::setStatus(PlayerInfo* player, const QuestStatus::Value & status)
Index: code/branches/cpp11_v2/src/modules/questsystem/Quest.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/Quest.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/Quest.cc	(revision 10765)
@@ -55,5 +55,5 @@
         RegisterObject(Quest);
 
-        this->parentQuest_ = NULL;
+        this->parentQuest_ = nullptr;
     }
 
@@ -183,5 +183,5 @@
         The index.
     @return
-        Returns a pointer to the sub-quest at the given index. NULL if there is no element at the given index.
+        Returns a pointer to the sub-quest at the given index. nullptr if there is no element at the given index.
     */
     const Quest* Quest::getSubQuest(unsigned int index) const
@@ -198,5 +198,5 @@
         }
 
-        return NULL; // If the index is greater than the number of elements in the list.
+        return nullptr; // If the index is greater than the number of elements in the list.
     }
 
@@ -207,5 +207,5 @@
         The index.
     @return
-        Returns a pointer to the QuestHint at the given index. NULL if there is no element at the given index.
+        Returns a pointer to the QuestHint at the given index. nullptr if there is no element at the given index.
     */
     const QuestHint* Quest::getHint(unsigned int index) const
@@ -221,5 +221,5 @@
             i--;
         }
-        return NULL; // If the index is greater than the number of elements in the list.
+        return nullptr; // If the index is greater than the number of elements in the list.
     }
 
@@ -230,5 +230,5 @@
         The index.
     @return
-        Returns a pointer to the fail QuestEffect at the given index. NULL if there is no element at the given index.
+        Returns a pointer to the fail QuestEffect at the given index. nullptr if there is no element at the given index.
     */
     const QuestEffect* Quest::getFailEffect(unsigned int index) const
@@ -244,5 +244,5 @@
             i--;
         }
-        return NULL; // If the index is greater than the number of elements in the list.
+        return nullptr; // If the index is greater than the number of elements in the list.
     }
 
@@ -253,5 +253,5 @@
         The index.
     @return
-        Returns a pointer to the complete QuestEffect at the given index. NULL if there is no element at the given index.
+        Returns a pointer to the complete QuestEffect at the given index. nullptr if there is no element at the given index.
     */
     const QuestEffect* Quest::getCompleteEffect(unsigned int index) const
@@ -267,5 +267,5 @@
             i--;
         }
-        return NULL; // If the index is greater than the number of elements in the list.
+        return nullptr; // If the index is greater than the number of elements in the list.
     }
 
@@ -280,5 +280,5 @@
     bool Quest::isInactive(const PlayerInfo* player) const
     {
-        if(player == NULL)
+        if(player == nullptr)
             return true;
         return this->getStatus(player) == QuestStatus::Inactive;
@@ -295,5 +295,5 @@
     bool Quest::isActive(const PlayerInfo* player) const
     {
-        if(player == NULL)
+        if(player == nullptr)
             return false;
         return this->getStatus(player) == QuestStatus::Active;
@@ -310,5 +310,5 @@
     bool Quest::isFailed(const PlayerInfo* player) const
     {
-        if(player == NULL)
+        if(player == nullptr)
             return false;
         return this->getStatus(player) == QuestStatus::Failed;
@@ -325,5 +325,5 @@
     bool Quest::isCompleted(const PlayerInfo* player) const
     {
-        if(player == NULL)
+        if(player == nullptr)
             return false;
         return this->getStatus(player) == QuestStatus::Completed;
Index: code/branches/cpp11_v2/src/modules/questsystem/QuestEffectBeacon.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/QuestEffectBeacon.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/QuestEffectBeacon.cc	(revision 10765)
@@ -113,8 +113,8 @@
 
         PlayerTrigger* pTrigger = orxonox_cast<PlayerTrigger*>(trigger);
-        PlayerInfo* player = NULL;
+        PlayerInfo* player = nullptr;
 
         // If the trigger is a PlayerTrigger.
-        if(pTrigger != NULL)
+        if(pTrigger != nullptr)
         {
             if(!pTrigger->isForPlayer())  // The PlayerTrigger is not exclusively for Pawns which means we cannot extract one.
@@ -126,5 +126,5 @@
             return false;
 
-        if(player == NULL)
+        if(player == nullptr)
         {
             orxout(verbose, context::quests) << "The QuestEffectBeacon was triggered by an entity other than a Pawn. (" << trigger->getIdentifier()->getName() << ")" << endl;
@@ -243,5 +243,5 @@
             i--;
         }
-        return NULL;
+        return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/modules/questsystem/QuestListener.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/QuestListener.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/QuestListener.cc	(revision 10765)
@@ -59,5 +59,5 @@
 
         this->mode_ = QuestListenerMode::All;
-        this->quest_ = NULL;
+        this->quest_ = nullptr;
     }
 
@@ -81,5 +81,5 @@
         XMLPortParam(QuestListener, "mode", setMode, getMode, xmlelement, mode);
 
-        if(this->quest_ != NULL)
+        if(this->quest_ != nullptr)
             this->quest_->addListener(this); // Adds the QuestListener to the Quests list of listeners.
 
@@ -117,5 +117,5 @@
         this->quest_ = QuestManager::getInstance().findQuest(id); // Find the Quest corresponding to the given questId.
 
-        if(this->quest_ == NULL) // If there is no such Quest.
+        if(this->quest_ == nullptr) // If there is no such Quest.
         {
             ThrowException(Argument, "This is bad! The QuestListener has not found a Quest with a corresponding id..");
Index: code/branches/cpp11_v2/src/modules/questsystem/QuestManager.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/QuestManager.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/QuestManager.cc	(revision 10765)
@@ -93,7 +93,7 @@
     bool QuestManager::registerQuest(Quest* quest)
     {
-        if(quest == NULL)
-        {
-            orxout(internal_error, context::quests) << "Quest pointer is NULL." << endl;
+        if(quest == nullptr)
+        {
+            orxout(internal_error, context::quests) << "Quest pointer is nullptr." << endl;
             return false;
         }
@@ -135,7 +135,7 @@
     bool QuestManager::registerHint(QuestHint* hint)
     {
-        if(hint == NULL)
-        {
-            orxout(internal_error, context::quests) << "Quest pointer is NULL." << endl;
+        if(hint == nullptr)
+        {
+            orxout(internal_error, context::quests) << "Quest pointer is nullptr." << endl;
             return false;
         }
@@ -173,5 +173,5 @@
     @return
         Returns a pointer to the Quest with the input id.
-        Returns NULL if there is no Quest with the given questId.
+        Returns nullptr if there is no Quest with the given questId.
     @throws
         Throws an exception if the given questId is invalid.
@@ -188,5 +188,5 @@
         else
         {
-           quest = NULL;
+           quest = nullptr;
            orxout(internal_warning, context::quests) << "The quest with id {" << questId << "} is nowhere to be found." << endl;
         }
@@ -202,5 +202,5 @@
     @return
         Returns a pointer to the QuestHint with the input id.
-        Returns NULL if there is no QuestHint with the given hintId.
+        Returns nullptr if there is no QuestHint with the given hintId.
     @throws
         Throws an exception if the given hintId is invalid.
@@ -217,5 +217,5 @@
         else
         {
-           hint = NULL;
+           hint = nullptr;
            orxout(internal_warning, context::quests) << "The hint with id {" << hintId << "} is nowhere to be found." << endl;
         }
@@ -237,5 +237,5 @@
         for(std::map<std::string, Quest*>::iterator it = this->questMap_.begin(); it != this->questMap_.end(); it++)
         {
-            if(it->second->getParentQuest() == NULL && !it->second->isInactive(player))
+            if(it->second->getParentQuest() == nullptr && !it->second->isInactive(player))
                 numQuests++;
         }
@@ -257,8 +257,8 @@
         for(std::map<std::string, Quest*>::iterator it = this->questMap_.begin(); it != this->questMap_.end(); it++)
         {
-            if(it->second->getParentQuest() == NULL && !it->second->isInactive(player) && index-- == 0)
+            if(it->second->getParentQuest() == nullptr && !it->second->isInactive(player) && index-- == 0)
                 return it->second;
         }
-        return NULL;
+        return nullptr;
     }
 
@@ -275,5 +275,5 @@
     int QuestManager::getNumSubQuests(Quest* quest, PlayerInfo* player)
     {
-        if(quest == NULL)
+        if(quest == nullptr)
             return this->getNumRootQuests(player);
 
@@ -300,5 +300,5 @@
     Quest* QuestManager::getSubQuest(Quest* quest, PlayerInfo* player, int index)
     {
-        if(quest == NULL)
+        if(quest == nullptr)
             return this->getRootQuest(player, index);
 
@@ -309,5 +309,5 @@
                 return *it;
         }
-        return NULL;
+        return nullptr;
     }
 
@@ -354,5 +354,5 @@
                 return *it;
         }
-        return NULL;
+        return nullptr;
     }
 
@@ -367,5 +367,5 @@
     Quest* QuestManager::getParentQuest(Quest* quest)
     {
-        OrxAssert(quest, "The input Quest is NULL.");
+        OrxAssert(quest, "The input Quest is nullptr.");
         return quest->getParentQuest();
     }
@@ -381,5 +381,5 @@
     QuestDescription* QuestManager::getDescription(Quest* item)
     {
-        OrxAssert(item, "The input Quest is NULL.");
+        OrxAssert(item, "The input Quest is nullptr.");
         return item->getDescription();
     }
@@ -395,5 +395,5 @@
     QuestDescription* QuestManager::getDescription(QuestHint* item)
     {
-        OrxAssert(item, "The input QuestHint is NULL.");
+        OrxAssert(item, "The input QuestHint is nullptr.");
         return item->getDescription();
     }
@@ -409,5 +409,5 @@
     const std::string QuestManager::getId(Quest* item) const
     {
-        OrxAssert(item, "The input Quest is NULL.");
+        OrxAssert(item, "The input Quest is nullptr.");
         return item->getId();
     }
@@ -423,5 +423,5 @@
     const std::string QuestManager::getId(QuestHint* item) const
     {
-        OrxAssert(item, "The input QuestHint is NULL.");
+        OrxAssert(item, "The input QuestHint is nullptr.");
         return item->getId();
     }
@@ -440,8 +440,8 @@
     {
         PlayerInfo* player = GUIManager::getInstance().getPlayer(guiName);
-        if(player == NULL)
+        if(player == nullptr)
         {
             orxout(internal_error, context::quests) << "GUIOverlay with name '" << guiName << "' has no player." << endl;
-            return NULL;
+            return nullptr;
         }
 
Index: code/branches/cpp11_v2/src/modules/questsystem/effects/AddQuest.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/effects/AddQuest.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/effects/AddQuest.cc	(revision 10765)
@@ -90,5 +90,5 @@
         {
             Quest* quest = QuestManager::getInstance().findQuest(this->getQuestId());
-            if(quest == NULL || !quest->start(player))
+            if(quest == nullptr || !quest->start(player))
                return false;
         }
Index: code/branches/cpp11_v2/src/modules/questsystem/effects/AddQuestHint.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/effects/AddQuestHint.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/effects/AddQuestHint.cc	(revision 10765)
@@ -113,5 +113,5 @@
         {
             QuestHint* hint = QuestManager::getInstance().findHint(this->hintId_);
-            if(hint == NULL || !hint->setActive(player))
+            if(hint == nullptr || !hint->setActive(player))
                 return false;
         }
Index: code/branches/cpp11_v2/src/modules/questsystem/effects/AddReward.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/effects/AddReward.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/effects/AddReward.cc	(revision 10765)
@@ -90,5 +90,5 @@
             i--;
         }
-        return NULL;
+        return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/modules/questsystem/effects/CompleteQuest.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/effects/CompleteQuest.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/effects/CompleteQuest.cc	(revision 10765)
@@ -92,5 +92,5 @@
         {
             quest = QuestManager::getInstance().findQuest(this->getQuestId());
-            if(quest == NULL || !quest->complete(player))
+            if(quest == nullptr || !quest->complete(player))
                return false;
         }
Index: code/branches/cpp11_v2/src/modules/questsystem/effects/FailQuest.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/effects/FailQuest.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/effects/FailQuest.cc	(revision 10765)
@@ -91,5 +91,5 @@
         {
             quest = QuestManager::getInstance().findQuest(this->getQuestId());
-            if(quest == NULL || !quest->fail(player))
+            if(quest == nullptr || !quest->fail(player))
                return false;
         }

Index: code/branches/cpp11_v2/src/modules/questsystem/QuestHint.cc
===================================================================
--- code/branches/cpp11_v2/src/modules/questsystem/QuestHint.cc	(revision 10732)
+++ code/branches/cpp11_v2/src/modules/questsystem/QuestHint.cc	(revision 10765)
@@ -88,5 +88,5 @@
     bool QuestHint::isActive(const PlayerInfo* player) const
     {
-        if(player == NULL) // If the player is NULL, the Quest obviously can't be active.
+        if(player == nullptr) // If the player is nullptr, the Quest obviously can't be active.
             return false;
 